@@ -1,6 +1,14 @@
-from abstract_utilities import convert_to_percentage,read_from_file,eatAll,make_list
-from abstract_utilities.type_utils import is_number
-from abstract_utilities.parse_utils import num_tokens_from_string,chunk_source_code,chunk_any_to_tokens
+from abstract_utilities import (
+    convert_to_percentage,
+    read_from_file,
+    eatAll,
+    make_list,is_number
+)
+from abstract_utilities.parse_utils import (
+    num_tokens_from_string,
+    chunk_source_code,
+    chunk_any_to_tokens,
+)
 from ..model_selection.ModelBuilder import ModelManager
 from ..instruction_selection import InstructionManager
 from ..api_selection.ApiBuilder import ApiManager
@@ -363,12 +371,9 @@ class PromptManager:
         Returns:
             dict: A dictionary representing the prompt for the chatbot.
         """
-        print(chunk_token_distribution_number)
-        print(self.instruction_data)
         self.prompt_as_previous=prompt_as_previous
         self.notation_text = notation
         self.prompt_as_previous_text=prompt_as_previous
-        print(prompt_as_previous)
         if prompt_as_previous and isinstance(prompt_as_previous,str):
             previous_request_data = self.request_data[chunk_token_distribution_number][:chunk_number]
             remaining_request_data = self.request_data[chunk_token_distribution_number][chunk_number:]
